Automaticaly run a data processing pipeline by European Southern Observatory.

The function esopipeline will take an instrument descriptor (e.g. gravity) 
and run the various esorex recipes on a set of raw frames and static
calibration files.  

It is equivalent to esoreflex but in the console.

INSTALL REQUIREMENTS

You need a 
(1) a relatively recent CPL and esorex installed
(2) the instrument recipes installed for: GRAVITY.
(3) a recent python 3

Only for GRAVITY for the moment...
